@@ -67,7 +67,7 @@
 #define CLIENT_ID_PARAM "ClientID"
 #define ACCOUNT_ID_PARAM "accountID_RET"
 
-#define LOGIN_SUCCESS "^http://vkontakte\\.ru/api/login_success\\.html.*"
+#define LOGIN_SUCCESS "^http://vkontakte\\.ru/api/(login_success|login_failure)\\.html.*"
 #define TITLE_VKONTAKTE "vkontakte"
 
 #ifdef TEST
