@@ -44,6 +44,12 @@ static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const s
 
 static error_type vk_driver_shutdown(const struct msa_module*);
 
+void msa_module_get_info(struct msa_module* d)
+{
+    d->name = DRIVER_NAME;
+    d->pic = VK_PIC;
+}
+
 /**
  * Module initialization. Prepare driverVK for work.
  *
@@ -53,11 +59,16 @@ static error_type vk_driver_shutdown(const struct msa_module*);
 error_type msa_module_init(struct msa_module* d)
 {
 #ifdef TEST
-    g_debug("TEST = %d", TEST);
+    msa_debug("TEST = %d", TEST);
 #endif
-    g_debug("driver %s: init START", DRIVER_NAME);
+    msa_debug("driver name = %s, id = %s: init START", DRIVER_NAME, d->id);
+
+    struct ProfileData *cp;
+    if(d->id == NULL)
+        cp = profile_create(DRIVER_ID);
+    else
+        cp = profile_create(d->id);
 
-    struct ProfileData *cp = profile_create(DRIVER_ID);
 //dispatcher must free memory(struct msa_module) when application shutdown
     d->name = g_strdup(DRIVER_NAME);
     d->id = g_strdup(cp->id);
@@ -70,7 +81,7 @@ error_type msa_module_init(struct msa_module* d)
     d->state = NOT_CONF;
     d->status = OFF;
 
-    g_debug("driver %s: init END", DRIVER_NAME);
+    msa_debug("driver %s: init END", DRIVER_NAME);
     return SUCCESS;
 }
 
@@ -86,13 +97,13 @@ static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const s
     xmlDocPtr reqXml = NULL, respXml = NULL;
     xmlDocPtr buffXml = NULL;
     if (info == NULL) {
-        g_debug("msa_module in NULL! can't perform request!");
+        msa_debug("msa_module in NULL! can't perform request!");
         return FAILURE;
     } else {
-        g_debug("get proxy settings %s %d ", info->proxy, info->port);
+        msa_debug("get proxy settings %s %d ", info->proxy, info->port);
     }
 
-    g_debug("vk_driver_send: START");
+    msa_debug("vk_driver_send: START");
 
     respXml = xmlNewDoc(BAD_CAST "1.0");
     //respXml->encoding = UTF8;
@@ -125,7 +136,7 @@ static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const s
 
     xmlFreeDoc(request);
     
-    vk_req(reqXml, respXml, info);
+    vk_req(reqXml, &respXml, info);
     xmlFreeDoc(reqXml);
 
     node = xmlDocGetRootElement(respXml);
@@ -153,7 +164,7 @@ static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const s
     *response = xmlCopyDoc(buffXml, 1);
     xmlFreeDoc(buffXml);
     g_free(source);
-    g_debug("vk_driver_send: END");
+    msa_debug("vk_driver_send: END");
     return SUCCESS;
 }
 
@@ -164,7 +175,7 @@ static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const s
  */
 static error_type vk_driver_shutdown(const struct msa_module *info)
 {
-    g_debug("vk_driver_shutdown");
+    msa_debug("vk_driver_shutdown");
     struct ProfileData *cp = (struct ProfileData *)profile_get_by_id(info->id);
     if (cp == NULL)
         return FAILURE;
